@@ -23,8 +23,9 @@
 
 #include "scim_anthy_action.h"
 
-AnthyAction::AnthyAction (const String &name, const String &key_bindings,
-                          PMF pmf)
+using namespace scim_anthy;
+
+Action::Action (const String &name, const String &key_bindings, PMF pmf)
     : m_name (name),
       m_pmf  (pmf),
       m_func (NULL)
@@ -32,8 +33,7 @@ AnthyAction::AnthyAction (const String &name, const String &key_bindings,
     scim_string_to_key_list (m_key_bindings, key_bindings);
 }
 
-AnthyAction::AnthyAction (const String &name, const String &key_bindings,
-                          Func func)
+Action::Action (const String &name, const String &key_bindings, Func func)
     : m_name (name),
       m_pmf  (NULL),
       m_func (func)
@@ -41,12 +41,12 @@ AnthyAction::AnthyAction (const String &name, const String &key_bindings,
     scim_string_to_key_list (m_key_bindings, key_bindings);
 }
 
-AnthyAction::~AnthyAction (void)
+Action::~Action (void)
 {
 }
 
 bool
-AnthyAction::perform (AnthyInstance *performer)
+Action::perform (AnthyInstance *performer)
 {
     if (m_pmf)
         return (performer->*m_pmf) ();
@@ -57,7 +57,7 @@ AnthyAction::perform (AnthyInstance *performer)
 }
 
 bool
-AnthyAction::perform (AnthyInstance *performer, const KeyEvent &key)
+Action::perform (AnthyInstance *performer, const KeyEvent &key)
 {
     if (!m_pmf && !m_func)
         return false;
@@ -73,12 +73,14 @@ AnthyAction::perform (AnthyInstance *performer, const KeyEvent &key)
 }
 
 bool
-AnthyAction::match_key_event (const KeyEvent &key)
+Action::match_key_event (const KeyEvent &key)
 {
     KeyEventList::const_iterator kit;
 
     for (kit = m_key_bindings.begin (); kit != m_key_bindings.end (); ++kit) {
-        if (key.code == kit->code && key.mask == kit->mask)
+        uint16 mask = key.mask;
+        mask &= ~SCIM_KEY_CapsLockMask;
+        if (key.code == kit->code && mask == kit->mask)
              return true;
     }
     return false;
